

TODO: TODO_80_99_84_41 `intercept` has no suggestions if selected via `func_id`

Search TODO to see test cases.

It might be something to do with `jump_tree` (generated via FS_33_76_82_84 composite forest)
having no relevant entry in that case.

